

import bpy
import os
bl_info = {
    "name": "Default Import/Export",
    "author": "Amandeep",
    "description": "Automatically apply default operator presets for Import/Export",
    "blender": (2, 90, 0),
    "version": (1, 0, 0),
    "warning": "",
    "category": "Object",
}

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTIBILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

class QMPrefs(bpy.types.AddonPreferences):
    bl_idname = __package__
    def draw(self,context):
        layout=self.layout
import_ops={'Collada (Default) (.dae)':'wm.collada_import','Alembic(.abc)':'wm.alembic_import','Universal Scene Description (.usd/.usds/.usda)':'wm.usd_import','SVG as Grease Pencil':'wm.gpencil_import_svg','Motion Capture (.bvh)':'import_anim.bvh','Scalable Vector Graphics (.svg)':'import_curve.svg'
,'Stanford (.ply)':'import_mesh.ply','Stl (.stl)':'import_mesh.stl','FBX (.fbx)':'import_scene.fbx','glTF 2.0 (.glb/.gltf)':'import_scene.gltf',
'Wavefront(.obj)':'import_scene.obj','X3D Extensible 3D (.x3d)':'import_scene.x3d'}
export_ops={'Collada (Default) (.dae)':'wm.collada_export','Alembic(.abc)':'wm.alembic_export','Universal Scene Description (.usd/.usds/.usda)':'wm.usd_export','Grease Pencil as SVG':'wm.gpencil_export_svg','Grease Pencil as PDF':'wm.gpencil_export_pdf','Motion Capture (.bvh)':'export_anim.bvh'
,'Stanford (.ply)':'export_mesh.ply','Stl (.stl)':'export_mesh.stl','FBX (.fbx)':'export_scene.fbx','glTF 2.0 (.glb/.gltf)':'export_scene.gltf',
'Wavefront(.obj)':'export_scene.obj','X3D Extensible 3D (.x3d)':'export_scene.x3d'}
skip_keys=['filepath','directory']
class DIE_OT_Merge(bpy.types.Operator):
    bl_idname = "die.callwithdefault"
    bl_label = "Import/Export"
    bl_description = "Select Loop"
    bl_options = {"REGISTER", "UNDO"}
    op:bpy.props.StringProperty(default="")

    def execute(self, context):
        presets_dir=os.path.join(os.path.dirname(os.path.dirname(os.path.dirname(__file__))),"presets","operator",self.op)
        useful={}
        props=""
        if os.path.isdir(presets_dir) and 'default.py' in os.listdir(presets_dir):
            with open(os.path.join(presets_dir,"default.py"),mode="r") as f:
                lines=f.readlines()
                for line in lines:
                    if " = " in line and "op." in line:
                        p1=line.split(" = ")[0]
                        if "op." in p1:
                            p2=eval(line.split(" = ")[1].replace("\n",''))
                        
                            useful[p1.replace("op.","")]=p2
            props=""
            i=0
            for key,value in useful.items():
                i+=1
                if i>0:
                    
                    if type(value)==str:
                        if key not in skip_keys:
                                  
                            props=props+","+key+"='"+str(value)+"'"
                    else:
                        props=props+","+key+"="+str(value)
        props=f"{props}"
        #print(props)
        eval(f"bpy.ops.{self.op}('INVOKE_DEFAULT'"+props+")")
        
        return {'FINISHED'}

class DIE_MT_Import(bpy.types.Menu):
    bl_label="Default Imports"
    def draw(self, context):
        layout=self.layout
        for key,value in import_ops.items():

            layout.operator("die.callwithdefault",text=key).op=value
class DIE_MT_Export(bpy.types.Menu):
    bl_label="Default Exports"
    def draw(self, context):
        layout=self.layout
        for key,value in export_ops.items():

            layout.operator("die.callwithdefault",text=key).op=value
def draw_into_import(self, context):
    layout=self.layout
    #layout.menu("DIE_MT_Import")
    for key,value in import_ops.items():

            layout.operator("die.callwithdefault",text=key).op=value
def draw_into_export(self, context):
    layout=self.layout
    #layout.menu("DIE_MT_Export")
    for key,value in export_ops.items():

            layout.operator("die.callwithdefault",text=key).op=value
classes = (DIE_OT_Merge,QMPrefs
           )

def register():
    from bpy.utils import register_class
    for cls in classes:
        register_class(cls)
    bpy.types.TOPBAR_MT_file_import.draw=lambda s,c:s.layout 
    bpy.types.TOPBAR_MT_file_export.draw=lambda s,c:s.layout 
    bpy.types.TOPBAR_MT_file_import.prepend(draw_into_import)
    bpy.types.TOPBAR_MT_file_export.prepend(draw_into_export)


def unregister():

    from bpy.utils import unregister_class

    for cls in reversed(classes):
        unregister_class(cls)
    bpy.types.TOPBAR_MT_file_import.remove(draw_into_import)
    bpy.types.TOPBAR_MT_file_export.remove(draw_into_export)
if __name__ == "__main__":
    register()
